@@ -419,7 +419,6 @@ int handleserverdata()
 	int i;
 	char ch;
 	char stringbuffer[READ_BUFFER_LENGTH + 1];
-	char safe_string[READ_BUFFER_LENGTH + 1];
         char pong[STRINGLEN + 1];
         size_t br;
         char *ptr;
@@ -459,7 +458,8 @@ int handleserverdata()
 	/* here we log all the server traffic, prefix with timestamp */
 	if((index(mystate->flags, (int)'l') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
 		/* it doesn't matter if logging fails */
-		oer_doquery("handleserverdata", OER_DEBUG_NOISE, "INSERT INTO raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysqlsafestr(stringbuffer, safe_string, READ_BUFFER_LENGTH));
+		mysql_real_escape_string(&mystate->mysqldb.mysqldbconn, mysql_safe_str1, stringbuffer, strlen(stringbuffer));
+		oer_doquery("handleserverdata", OER_DEBUG_NOISE, "INSERT INTO raw VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str1);
 	}
 	if((ptr = (char *) strstr(stringbuffer, "PING :")) != NULL) {
 		snprintf(pong, STRINGLEN, "PONG :%s\n", ptr + 6);
@@ -557,23 +557,24 @@ int processtimeds()
 
 int processactions(struct timed *t)
 {
+	int delta;
+	int weight;
         struct channel *this;
+
+        delta = mystate->now - mystate->last_action.ts;
 #ifdef DEBUG
 	/* prevent initial flooding of the console */
         if((mystate->now - mystate->current_server->linkup) >= 10) {
 		oer_debug(OER_DEBUG_NOISE, "processactions(\"%lu\")\n", t->at);
-		oer_debug(OER_DEBUG_INFO, "processactions->last action at %lu / delta %d / barrier %d\n", mystate->last_action.ts, (int) (mystate->now - mystate->last_action.ts), mystate->last_action.barrier);
+		oer_debug(OER_DEBUG_INFO, "processactions->last action at %lu / delta %d / barrier %d\n", mystate->last_action.ts, delta, mystate->last_action.barrier);
 	}
 #endif
-        if(t->type != OER_TIMED_TYPE_KICK) {
-                if(t->prio == OER_TIMED_PRIORITY_CHANNEL_HANDLING ||
-                   t->prio == OER_TIMED_PRIORITY_CHANNEL_PROTECTION) {
-                        if(mystate->now > mystate->last_action.ts || mystate->last_action.barrier < 5) {
-				mystate->last_action.ts = mystate->now;
-                                mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
-                                return 1;
-                        }
-                }
+	if((t->prio == OER_TIMED_PRIORITY_CHANNEL_HANDLING || t->prio == OER_TIMED_PRIORITY_CHANNEL_PROTECTION) && t->type != OER_TIMED_TYPE_KICK) {
+		if(delta || mystate->last_action.barrier < 5) {
+			mystate->last_action.ts = mystate->now;
+			mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
+			return 1;
+		}
         }
         if(mystate->last_action.barrier) {
                 return 0;
@@ -594,6 +595,13 @@ int processactions(struct timed *t)
                         mystate->last_action.barrier += 3 + (strlen(t->command) / 50);
                 }
                 break;
+        case OER_TIMED_PRIORITY_CTCP:
+                /* this is a flood protection, somebody could flood an otherwise
+                   idle oer by sending it ctcp queries in fixed intervals of 1..2
+                   seconds, it all comes down to ircd's flood detection */
+                weight = (delta) ? (2 / (delta + 1)) : 2;
+                mystate->last_action.barrier += weight + 2 + (strlen(t->command) / 50);
+                break;
         case OER_TIMED_PRIORITY_NOTICE:
         case OER_TIMED_PRIORITY_PRIVMSG:
                 mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
@@ -610,10 +618,3 @@ int processactions(struct timed *t)
         }
         return 1;
 }
-
-
-
-
-
-
-
