@@ -256,7 +256,7 @@ enum OER_FLAGS_TYPE {
         OER_FLAGS_TYPE_USER
 };
 
-#define OER_FLAGS_GLOBAL "dfglmnpqs"
+#define OER_FLAGS_GLOBAL "dfglmnopqs"
 #define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwxX"
 #define OER_FLAGS_ADMIN "dn"
 #define OER_FLAGS_USER "!adfmovrx"
@@ -360,7 +360,7 @@ enum OER_FLAGS_TYPE {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-32, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-33, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -609,6 +609,7 @@ struct state {
 	char realname[STRINGLEN + 1];
 	char flags[FLAGLEN + 1];
 	char ident[STRINGLEN + 1];
+	char adminsfrom[STRINGLEN + 1];
 	char usersfrom[STRINGLEN + 1];
 	char prefix[TINYSTRINGLEN + 1];
 	char state[STRINGLEN + 1];
