@@ -62,12 +62,14 @@ int main(int argc, char *argv[])
         char *locptr;
 #endif
 	char config[TINYSTRINGLEN + 1];
+        char adminsfrom[STRINGLEN + 1];
         char usersfrom[STRINGLEN + 1];
         char state[STRINGLEN + 1];
 	int retval;
 	int c;
 	int do_help;
 	int do_version;
+	int do_adminsfrom;
 	int do_usersfrom;
 	int do_state;
 	fd_set rsock;
@@ -84,11 +86,17 @@ int main(int argc, char *argv[])
 	do_signals = 1;
 	do_version = 0;
 	do_tempoutput = 1;
+	do_adminsfrom = 0;
 	do_usersfrom = 0;
 	do_state = 0;
 	strncpy(config, "oer+MySQL.conf", TINYSTRINGLEN);
-        while((c = getopt(argc, argv, "cd:f:hsu:t:v")) > 0) {
+        while((c = getopt(argc, argv, "a:cd:f:hsu:t:v")) > 0) {
 		switch(c) {
+		case 'a':
+			strncpy(adminsfrom, optarg, STRINGLEN);
+			oer_debug(OER_DEBUG_INFO, "main->I will get my admins with ident %s\n", adminsfrom);
+			do_adminsfrom = 1;
+			break;
 		case 'c':
 			do_console = 1;
 			break;
@@ -175,6 +183,9 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 	strcpy(mystate->config, config);
+	if(do_adminsfrom) {
+		strcpy(mystate->adminsfrom, adminsfrom);
+	}
 	if(do_usersfrom) {
 		strcpy(mystate->usersfrom, usersfrom);
 	}
@@ -189,13 +200,17 @@ int main(int argc, char *argv[])
 		oer_debug(OER_DEBUG_FATAL, "main->mysql_real_connect() failed: %s\n", mysql_error(&mystate->mysqldb.mysqldbconn));
 		exit(EXIT_FAILURE);
         }
+        if(do_console) {
+		oer_debug(OER_DEBUG_INFO, "console mode is on (debug messages will be shown on screen)\n");
+	}
+	/* switch temp output off for initenv() */
+	do_tempoutput = 0;
 	if(!initenv()) {
                 oer_debug(OER_DEBUG_FATAL, "main->initenv() failed\n");
 		exit(EXIT_FAILURE);
         }
-        if(do_console) {
-		oer_debug(OER_DEBUG_INFO, "console mode is on (debug messages will be shown on screen)\n");
-	}
+	/* on again */
+	do_tempoutput = 1;
 	if(index(mystate->flags, (int)'o') != NULL) {
 		oer_debug(OER_DEBUG_INFO, "debug messages will be saved to MySQL\n");
 	}
@@ -220,7 +235,7 @@ int main(int argc, char *argv[])
 		close(STDERR_FILENO);
 		do_console = 0;
 	}
-	/* from now on we write to console and/or database */
+	/* from now on we will write to console/database */
 	do_tempoutput = 0;
 	establishconnection();
 	if(mystate->bailout) {
