@@ -953,6 +953,7 @@ void parseirc(char *serveroutput)
 				/* check if the last user on channel was de-opped, if
 				   so activate requestop */
                                 if(ischanopless(this)) {
+					this->requestop_now = 1;
                                         this->requestop = mystate->now + 300;
                                 }
                                 if(isme(target)) {
@@ -1685,6 +1686,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->QUIT\n");
 #endif
+		restptr = commandline + prevppos;
 		if(!isopa(userhost)) {
 			return;
 		}
@@ -1993,6 +1995,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->MASSMESSAGE\n");
 #endif
+		restptr = commandline + prevppos;
 		if(!isopa(userhost)) {
 			return;
 		}
@@ -2237,10 +2240,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
-			return;
-		}
-                if(!isatleastopnow(this, nick, userhost)) {
+		if(haschanflags(this, "X") && !isadmin(this, userhost)) {
+                        return;
+                } else if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                        return;
+                } else if(!isatleastopnow(this, nick, userhost)) {
                         return;
                 }
 		if(strlen(restptr) > 0) {
@@ -2255,10 +2259,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
-			return;
-		}
-                if(!isatleastopnow(this, nick, userhost)) {
+		if(haschanflags(this, "X") && !isadmin(this, userhost)) {
+                        return;
+                } else if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                        return;
+                } else if(!isatleastopnow(this, nick, userhost)) {
                         return;
                 }
 		if(!strlen(restptr)) {
@@ -2270,6 +2275,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->RAW\n");
 #endif
+		restptr = commandline + prevppos;
 		if(!isopa(userhost)) {
 			return;
 		}
